# swagger-client
Configure client certificate support for your websites or web applications. <br/>Manage and upload a Certificate Revocation List (CRL) file to verify whether certificates are valid and trustworthy. <br/>For full feature documentation, see <a href=\"https://docs.imperva.com/bundle/cloud-application-security/page/more/client-certificate-support.htm\">Client Certificate Support</a>.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: x-API-Id
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Id'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Id'] = 'Bearer'
# Configure API key authorization: x-API-Key
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CRLApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The Imperva ID for the website.
crl_file = 'crl_file_example' # str |  (optional)
name = 'name_example' # str |  (optional)

try:
    # Add CRL to site
    api_response = api_instance.add_crl(site_id, crl_file=crl_file, name=name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CRLApi->add_crl: %s\n" % e)

# Configure API key authorization: x-API-Id
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Id'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Id'] = 'Bearer'
# Configure API key authorization: x-API-Key
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CRLApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The Imperva ID for the website.
crl_id = 789 # int | The Imperva ID for the CRL.
crl_file = 'crl_file_example' # str |  (optional)
name = 'name_example' # str |  (optional)

try:
    # Update existing CRL on site
    api_response = api_instance.full_update_crl(site_id, crl_id, crl_file=crl_file, name=name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CRLApi->full_update_crl: %s\n" % e)

# Configure API key authorization: x-API-Id
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Id'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Id'] = 'Bearer'
# Configure API key authorization: x-API-Key
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CRLApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The Imperva ID for the website.

try:
    # List site CRLs
    api_response = api_instance.list_crls(site_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CRLApi->list_crls: %s\n" % e)

# Configure API key authorization: x-API-Id
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Id'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Id'] = 'Bearer'
# Configure API key authorization: x-API-Key
configuration = swagger_client.Configuration()
configuration.api_key['x-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-API-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CRLApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The Imperva ID for the website.
crl_id = 789 # int | The Imperva ID for the CRL.

try:
    # Remove CRL from site
    api_instance.remove_crl(site_id, crl_id)
except ApiException as e:
    print("Exception when calling CRLApi->remove_crl: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.imperva.com/certificate-manager*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CRLApi* | [**add_crl**](docs/CRLApi.md#add_crl) | **POST** /sites/{siteId}/CRL | Add CRL to site
*CRLApi* | [**full_update_crl**](docs/CRLApi.md#full_update_crl) | **PUT** /sites/{siteId}/CRL/{crlId} | Update existing CRL on site
*CRLApi* | [**list_crls**](docs/CRLApi.md#list_crls) | **GET** /sites/{siteId}/CRL | List site CRLs
*CRLApi* | [**remove_crl**](docs/CRLApi.md#remove_crl) | **DELETE** /sites/{siteId}/CRL/{crlId} | Remove CRL from site
*ClientCertificatesApi* | [**add_client_ca_cert**](docs/ClientCertificatesApi.md#add_client_ca_cert) | **POST** /v2/accounts/{accountId}/client-certificates | Add client CA certificate to account
*ClientCertificatesApi* | [**assign_site_to_certificate**](docs/ClientCertificatesApi.md#assign_site_to_certificate) | **POST** /v2/sites/{siteId}/client-certificates/{certId} | Assign client CA certificate of the account to site
*ClientCertificatesApi* | [**deassign_cert_from_site**](docs/ClientCertificatesApi.md#deassign_cert_from_site) | **DELETE** /v2/sites/{siteId}/client-certificates/{certId} | Remove client CA certificate from site
*ClientCertificatesApi* | [**delete_client_ca_cert**](docs/ClientCertificatesApi.md#delete_client_ca_cert) | **DELETE** /v2/accounts/{accountId}/client-certificates/{certId} | Delete client CA certificate from account
*ClientCertificatesApi* | [**full_update_site_configuration**](docs/ClientCertificatesApi.md#full_update_site_configuration) | **PUT** /v2/sites/{siteId}/configuration/client-certificates | Overwrite the client CA certificate configuration (full update)
*ClientCertificatesApi* | [**get_all_certs_for_site**](docs/ClientCertificatesApi.md#get_all_certs_for_site) | **GET** /v2/sites/{siteId}/client-certificates | List all client CA certificates assigned to site
*ClientCertificatesApi* | [**get_site_configuration**](docs/ClientCertificatesApi.md#get_site_configuration) | **GET** /v2/sites/{siteId}/configuration/client-certificates | Get client CA certificate configuration for site
*ClientCertificatesApi* | [**list_client_ca_certs_by_account**](docs/ClientCertificatesApi.md#list_client_ca_certs_by_account) | **GET** /v2/accounts/{accountId}/client-certificates | List client CA certificates in account
*ClientCertificatesApi* | [**list_sites_by_cert**](docs/ClientCertificatesApi.md#list_sites_by_cert) | **GET** /v2/accounts/{accountId}/client-certificates/{certId} | Get client CA certificate information including assigned sites
*ClientCertificatesApi* | [**partial_update_site_configuration**](docs/ClientCertificatesApi.md#partial_update_site_configuration) | **POST** /v2/sites/{siteId}/configuration/client-certificates | Modify the client CA certificate configuration (partial update)

## Documentation For Models

 - [AccountIdClientcertificatesBody](docs/AccountIdClientcertificatesBody.md)
 - [CRLCrlIdBody](docs/CRLCrlIdBody.md)
 - [CRLDetails](docs/CRLDetails.md)
 - [ClientCACertificateDetails](docs/ClientCACertificateDetails.md)
 - [ClientCACertificateSiteConfiguration](docs/ClientCACertificateSiteConfiguration.md)
 - [SiteIdCRLBody](docs/SiteIdCRLBody.md)

## Documentation For Authorization


## x-API-Id

- **Type**: API key
- **API key parameter name**: x-API-Id
- **Location**: HTTP header

## x-API-Key

- **Type**: API key
- **API key parameter name**: x-API-Key
- **Location**: HTTP header


## Author


