w# swagger-client
This is an API for Imperva Client-Side Protection. Gain visibility into the JavaScript services making requests to your application along with their risk factors. Use these APIs to pull data and configure which services should have access to your application. For full feature documentation, see <a style=\"text-decoration:none\" href=\"https://docs.imperva.com/bundle/client-side-protection\">Client-Side Protection</a>

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.DomainsApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The numeric identifier of the site
domain_id = 'domain_id_example' # str | Domain reference id as received from getDomains operation

try:
    # Retrieve information about specific domain
    api_response = api_instance.get_domain(site_id, domain_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DomainsApi->get_domain: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DomainsApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The numeric identifier of the site
domain_id = 'domain_id_example' # str | Domain reference id as received from getDomains operation.

try:
    # Retrieve status details of a discovered domain
    api_response = api_instance.get_domain_allowance(site_id, domain_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DomainsApi->get_domain_allowance: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DomainsApi(swagger_client.ApiClient(configuration))
site_id = 789 # int | The numeric identifier of the site
significant = true # bool | Show only significant domains. If the service is part of the profile and/or frequently requested. The two values are 1 or 0. 1 = significant. 0 = not significant. (optional)
expand = true # bool | Expand domain object to include additional information. Adds #domainInfo and #domainReports fields. (optional)
resource = 'resource_example' # str | Show only domains with specific resource type (optional)
start = -1 # int | Start index of domains (optional) (default to -1)
length = -1 # int | Length of requested domains (optional) (default to -1)

try:
    # Retrieve list of all discovered domains
    api_response = api_instance.get_domains(site_id, significant=significant, expand=expand, resource=resource, start=start, length=length)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DomainsApi->get_domains: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DomainsApi(swagger_client.ApiClient(configuration))
body = swagger_client.DomainStatus() # DomainStatus | 
site_id = 789 # int | The numeric identifier of the site
domain_id = 'domain_id_example' # str | Domain reference id as received from getDomains operation

try:
    # Overwrite status of the a discovered domain
    api_response = api_instance.set_domain_allowance(body, site_id, domain_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DomainsApi->set_domain_allowance: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.imperva.com/csp-api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DomainsApi* | [**get_domain**](../../CSP/docs/DomainsApi.md#get_domain) | **GET** /v1/sites/{siteId}/domains/{domainId} | Retrieve information about specific domain
*DomainsApi* | [**get_domain_allowance**](../../CSP/docs/DomainsApi.md#get_domain_allowance) | **GET** /v1/sites/{siteId}/domains/{domainId}/status | Retrieve status details of a discovered domain
*DomainsApi* | [**get_domains**](../../CSP/docs/DomainsApi.md#get_domains) | **GET** /v1/sites/{siteId}/domains | Retrieve list of all discovered domains
*DomainsApi* | [**set_domain_allowance**](../../CSP/docs/DomainsApi.md#set_domain_allowance) | **PUT** /v1/sites/{siteId}/domains/{domainId}/status | Overwrite status of the a discovered domain
*EmailApi* | [**add_email**](../../CSP/docs/EmailApi.md#add_email) | **POST** /v1/sites/{siteId}/settings/emails/add | Add an email address to the notification list
*EmailApi* | [**get_emails**](../../CSP/docs/EmailApi.md#get_emails) | **GET** /v1/sites/{siteId}/settings/emails | Retrieve the notification recipient list
*EmailApi* | [**remove_email**](../../CSP/docs/EmailApi.md#remove_email) | **POST** /v1/sites/{siteId}/settings/emails/delete | Delete an email address from the notification list
*NotesApi* | [**add_domain_note**](../../CSP/docs/NotesApi.md#add_domain_note) | **POST** /v1/sites/{siteId}/domains/{domainId}/notes | Add notes to a discovered domain.
*NotesApi* | [**delete_note**](../../CSP/docs/NotesApi.md#delete_note) | **DELETE** /v1/sites/{siteId}/domains/{domainId}/notes | Delete notes from a discovered domain
*NotesApi* | [**get_domain_notes**](../../CSP/docs/NotesApi.md#get_domain_notes) | **GET** /v1/sites/{siteId}/domains/{domainId}/notes | Retrieve user notes for a discovered domain
*PreApprovedDomainsApi* | [**add_pre_approved_domain**](../../CSP/docs/PreApprovedDomainsApi.md#add_pre_approved_domain) | **POST** /v1/sites/{siteId}/preapprovedlist | Add a domain to pre-approved list
*PreApprovedDomainsApi* | [**delete_pre_approved_domain**](../../CSP/docs/PreApprovedDomainsApi.md#delete_pre_approved_domain) | **DELETE** /v1/sites/{siteId}/preapprovedlist/{preApprovedDomainId} | Delete the pre-approved domain
*PreApprovedDomainsApi* | [**get_pre_approved_domain**](../../CSP/docs/PreApprovedDomainsApi.md#get_pre_approved_domain) | **GET** /v1/sites/{siteId}/preapprovedlist/{preApprovedDomainId} | Retrieve the pre-approved domain
*PreApprovedDomainsApi* | [**get_pre_approved_domains**](../../CSP/docs/PreApprovedDomainsApi.md#get_pre_approved_domains) | **GET** /v1/sites/{siteId}/preapprovedlist | Retrieve list of pre-approved domains
*WebsitesApi* | [**get_discovery_status**](../../CSP/docs/WebsitesApi.md#get_discovery_status) | **GET** /v1/sites/{siteId}/discovery | Retrieve discovery status of a website
*WebsitesApi* | [**get_enforcement_mode**](../../CSP/docs/WebsitesApi.md#get_enforcement_mode) | **GET** /v1/sites/{siteId}/mode | Retrieve protection mode of a website
*WebsitesApi* | [**get_google_tracking_ids**](../../CSP/docs/WebsitesApi.md#get_google_tracking_ids) | **GET** /v1/sites/{siteId}/tracking-ids | Retrieve list of Google tracking IDs detected for this website
*WebsitesApi* | [**get_site**](../../CSP/docs/WebsitesApi.md#get_site) | **GET** /v1/sites/{siteId} | Retrieve website configuration and status details
*WebsitesApi* | [**get_site_reputation**](../../CSP/docs/WebsitesApi.md#get_site_reputation) | **GET** /v1/sites/{siteId}/domain_reputation | Retrieve Osint scores for this website
*WebsitesApi* | [**get_site_settings**](../../CSP/docs/WebsitesApi.md#get_site_settings) | **GET** /v1/sites/{siteId}/settings | Retrieve website settings
*WebsitesApi* | [**get_sites**](../../CSP/docs/WebsitesApi.md#get_sites) | **GET** /v1/sites | Retrieve all websites for current account
*WebsitesApi* | [**set_discovery_status**](../../CSP/docs/WebsitesApi.md#set_discovery_status) | **PUT** /v1/sites/{siteId}/discovery | Change discovery status of a website
*WebsitesApi* | [**set_enforcement_mode**](../../CSP/docs/WebsitesApi.md#set_enforcement_mode) | **PUT** /v1/sites/{siteId}/mode | Change protection mode of a website
*WebsitesApi* | [**set_site**](../../CSP/docs/WebsitesApi.md#set_site) | **PUT** /v1/sites/{siteId} | Change website configuration and status details

## Documentation For Models

 - [Analytics](../../CSP/docs/Analytics.md)
 - [Discovery](../../CSP/docs/Discovery.md)
 - [DiscoveryStatus](../../CSP/docs/DiscoveryStatus.md)
 - [Domain](../../CSP/docs/Domain.md)
 - [DomainInfo](../../CSP/docs/DomainInfo.md)
 - [DomainObfuscationReport](../../CSP/docs/DomainObfuscationReport.md)
 - [DomainQuality](../../CSP/docs/DomainQuality.md)
 - [DomainReport](../../CSP/docs/DomainReport.md)
 - [DomainReputation](../../CSP/docs/DomainReputation.md)
 - [DomainRisk](../../CSP/docs/DomainRisk.md)
 - [DomainStatus](../../CSP/docs/DomainStatus.md)
 - [EmailList](../../CSP/docs/EmailList.md)
 - [FullNote](../../CSP/docs/FullNote.md)
 - [Mode](../../CSP/docs/Mode.md)
 - [PreApprovedDomain](../../CSP/docs/PreApprovedDomain.md)
 - [SSLCertificateInfo](../../CSP/docs/SSLCertificateInfo.md)
 - [SetSite](../../CSP/docs/SetSite.md)
 - [ShallowPreApprovedDomain](../../CSP/docs/ShallowPreApprovedDomain.md)
 - [Site](../../CSP/docs/Site.md)
 - [SiteReputation](../../CSP/docs/SiteReputation.md)
 - [SiteSettings](../../CSP/docs/SiteSettings.md)
 - [TimeMeasurement](../../CSP/docs/TimeMeasurement.md)
 - [UrlObfuscationReport](../../CSP/docs/UrlObfuscationReport.md)

## Documentation For Authorization


## api_id

- **Type**: API key
- **API key parameter name**: x-API-Id
- **Location**: HTTP header

## api_key

- **Type**: API key
- **API key parameter name**: x-API-Key
- **Location**: HTTP header


## Author


